
# pypaq

little python tools, useful mainly for tasks related to Machine Learning, NLP, statistics, multiprocessing

-----------------

#### naming conventions used


| pattern      | description |
|--------------| ---          
| n_*          | number of * 
| *L           | list      
| *D           | dict
| *_ix         | index (int)
| *_id         | id (int or str) 
| *_dir, *_DIR | directory, folder, relative or absolute
| *_fn, *_FN   | file name (without dir)
| *_fp, *_FP   | full path (dir + file_name), relative or absolute
